import { ComponentClass } from 'react';
import Taro, { Component, Config } from '@tarojs/taro';
import { View, Button, Text, ScrollView } from '@tarojs/components';
import { connect } from '@tarojs/redux';

import OrderItem from '../components/OrderItem/OrderItem';

import './OrderList.scss';

import { toggleOrderState } from './actions';
import { StoreState } from './store';

type PageStateProps = {
  OrderList: StoreState;
};
type PageDispatchProps = {
  toggleOrderState: (state: String) => void;
};

type PageOwnProps = {};

type PageProps = PageStateProps & PageDispatchProps & PageOwnProps;

interface OrderList {
  props: PageProps;
}

@connect(
  ({ OrderList }) => ({
    OrderList,
  }),
  dispatch => ({
    toggleOrderState(state: String) {
      dispatch(toggleOrderState(state));
    },
  }),
)
class OrderList extends Component {
  config: Config = {
    navigationBarTitleText: '订单',
  };
  constructor(props: PageProps) {
    super(props);
    this.state = {};
  }

  render() {
    const {
      OrderList: { orderState },
      toggleOrderState,
    } = this.props;

    return (
      <View className='OrderList'>
        <View className='Tab'>
          <Text
            className={`Tab-item ${orderState === '1' ? 'active' : ''}`}
            onClick={() => toggleOrderState('1')}>
            待付款
          </Text>
          <Text
            className={`Tab-item ${orderState === 'all' ? 'active' : ''}`}
            onClick={() => toggleOrderState('all')}>
            全部
          </Text>
        </View>
        <ScrollView
          className='OrderList-Content'
          scrollY
          scrollWithAnimation
          scrollTop={0}>
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
          <OrderItem />
        </ScrollView>
      </View>
    );
  }
}

export default OrderList as ComponentClass<PageOwnProps>;
